import React, { useEffect, useRef, useState } from "react";
import { propTypes } from "react-bootstrap/esm/Image";
import MenuItem from "./menuItem";
import {Link} from "react-router-dom";
import {FiGift, FiLogIn, FiLogOut, FiMail, FiUser} from "react-icons/fi";

export default function Account({ hideMenu, isUserLoggedIn }: { hideMenu: Function; isUserLoggedIn: boolean; }) {
   const menuRef = useRef(null);

   useEffect(() => {
      const handleClickOutside = (event: Event) => {
         if (menuRef.current && !menuRef.current.contains(event.target)) {
            hideMenu();
         }
      };
      document.addEventListener("mousedown", handleClickOutside);
      return () => {
         document.removeEventListener("mousedown", handleClickOutside);
      };
   }, [hideMenu]);

   return (
      <div className="item-list" ref={menuRef} >

         {!isUserLoggedIn && (
            <div onClick={()=>{hideMenu()}}>
               <NewMenuItem
                  name="Create Account"
                  icon={FiUser}
                  to="/create-account"
               />
            </div>
         )}

         {!isUserLoggedIn && (
            <div onClick={()=>{hideMenu()}}>
               <NewMenuItem
                  name="Log In"
                  icon={FiLogIn}
                  to="/login"
               />
            </div>
         )}

         {isUserLoggedIn && (
            <div onClick={()=>{hideMenu()}}>
               <NewMenuItem
                  name="My profile"
                  icon={FiUser}
                  to="/my-profile"
               />
            </div>
         )}

         {isUserLoggedIn && (
            <div onClick={()=>{hideMenu()}}>
               <NewMenuItem
                  name="Log Out"
                  icon={FiLogOut}
                  to="/logout"
               />
            </div>
         )}
         <hr />
         <div onClick={()=>{hideMenu()}}>
             <NewMenuItem
                 name="Our Offers"
                 icon={FiGift}
                 to="/our-offers"
             />
         </div>
         <div onClick={()=>{hideMenu()}}>
            <NewMenuItem
               name="Contact Us"
               icon={FiMail}
               to="/contact-us"
            />
         </div>
      </div>
   );
}

const NewMenuItem = ({name, icon: Icon, to}) => {
  return (
      <Link to={to}>
          <div className="d-flex align-items-center new-menu-item">
              <Icon size={20}/><span>{name}</span>
          </div>
      </Link>
  )
}